#!/bin/sh
set -eu

mkdir -p public

PROJECT_UC="$1"
PROJECT="$2"
MAILING_LIST="$3"
TLD="$(cat aux/tld.txt)"

TODOS_ADD_REGEX='s/^## (TODO|DOING|WAITING|MEETING|INACTIVE|NEXT|CANCELLED|DONE) (.*) \{#(.*?)\}$/## <a href="#\3"><span class="\1">\1<\/span> \2<\/a>\n<span class="header-anchor" id="\3">#\3<\/span>\n/'
TODOS_CLEANUP_REGEX1='s/(<a><a)/<a/'
TODOS_CLEANUP_REGEX2='s/<\/a><\/a>/<\/a>/'

TAGS_REGEX='s/tag:([\w-]+)/<span class="tag">\1<\/span>/g'

sed -e "s:@PROJECT_UC@:$PROJECT_UC:g"     \
    -e "s:@PROJECT@:$PROJECT:g"           \
    -e "s:@MAILING_LIST@:$MAILING_LIST:g" \
    -e "s:@TLD@:$TLD:g"                   \
    < aux/workflow/preamble.md | \
	printf \
		'%s\n\n%s' \
		"$(cat -)" \
		"$(perl -pe "$TODOS_ADD_REGEX" TODOs.md | perl -pe "$TAGS_REGEX")" | \
	pandoc \
		--toc                                  \
		--highlight-style pygments             \
		--toc-depth=2                          \
		-s                                     \
		--metadata title="$PROJECT_UC - TODOs" \
		--metadata lang=en                     \
		-r commonmark                          \
		-w html                                \
		-H aux/workflow/favicon.html           \
		-H aux/workflow/style.css              \
		| \
	perl -pe "$TODOS_CLEANUP_REGEX1" | \
	perl -pe "$TODOS_CLEANUP_REGEX2" \
	> public/TODOs.html
